% Ausbreitung eines Wellenpaketes ohne/mit Dispersion

% Die berlagerung vieler harmonischer Wellen 
% zu fester Zeit ergibt einen lokalisierten Puls,
% der je nach Zeitpunkt t an unterschiedlichem Ort ist.
%
% Es werden harmonische Wellen berlagert mit rumlichen Frequenzen k, 
% phys. Dimension [k]=rad/m. 
% Die zeitliche Frequenz ist omega=w=k*v(k) (Symbol w fr omega),
% mit der Phasengeschwindigkeit v(k)=w(k)/k, [v]=m/s
% Die Phasengeschwindigkeit v kann eine Dispersion haben: 
% v=v0+dv/dk*(k-k0), mit v0 und dv/dk genommen bei k0. 
% Fr dv/dk=0 ist die Dispersion gleich Null.
% 
% Die Amplitude aller beitragenden Wellen ist so gewhlt
% dass der Beitrag der Welle mit k=k0 maximal ist und Wellen mit 
% kleineren und greren k entsprechend einer Gauss-
% Verteilung exp(-((k-k0)^2/(2*Dk^2)) beitragen. 

z=-2:0.001:3;  % betrachteter Raumbereich (in m)
k0=2*pi*20; % Welle mit max. Gewicht hat 20 Perioden pro m 
dk=2*pi*0.1; % Diskretisierung von k
Dk=2*pi*2; % Breite der Verteilung, siehe Definition der Gaussfkt.
v0=1;  % Ausbreitungs(Phasen-)geschwindigkeit bei k0
% dvdk=0.075/(2*pi); % Ableitung der Phasengeschwindigkeit dv/dk 
dvdk=-0.01/(2*pi); % Ableitung der Phasengeschwindigkeit dv/dk 
% dvdk=0; % keine Dispersion
% Beziehung zwischen Gruppengeschwindigkeit vg=dw/dk 
% und Phasengeschwindigkeit v(k)=w(k)/k ist vg=v+k*dv/dk
vg=v0+k0*dvdk; 
Maxxi=60; % fr Darstellung
[v0, vg]

t=0;  % fester Zeitpunkt
k=k0;  % rumliche Frequenz (n Halbwellen in z=1:100)
% wiederkehrende Befehle
Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
% Ende wiederkehrende Befehle
xi0=xi; % Welle mit k0 (fr die grafische Darstellung)
xi=zeros(size(xi));  % zur Initialisierung
xiwp=zeros(size(xi));  % zur Initialisierung
for k=k0-3*Dk:dk:k0+3*Dk;  % harmonische Wellen in 3*Dk links und rechts des Max.
    %
    Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
    vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
    xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
    %
    xiwp=xiwp+xi;  % Wellenpaket = Summe der harmonischen Wellen
end
figure(12)
plot(z,10*xi0,z,xiwp);
axis([min(z) max(z) -Maxxi Maxxi]);
title([' t * v_g = ',num2str(t*vg),'    t * v_0 = ',num2str(t*v0)]);
% Bei t=0 hat das Wellenpaket die minimale Unschrfe!


t=1/vg;  % fester Zeitpunkt so dass t*vg=1m
k=k0;  % rumliche Frequenz (n Halbwellen in z=1:100)
% 
Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
% 
xi0=xi; % Welle mit k0 (fr die grafische Darstellung)
xi=zeros(size(xi));  % zur Initialisierung
xiwp=zeros(size(xi));  % zur Initialisierung
for k=k0-3*Dk:dk:k0+3*Dk;  % harmonische Wellen in 3*Dk links und rechts des Max.
    %
    Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
    vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
    xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
    %
    xiwp=xiwp+xi;  % Wellenpaket = Summe der harmonischen Wellen
end
figure(22)
plot(z,10*xi0,z,xiwp);
axis([min(z) max(z) -Maxxi Maxxi]);
title([' t * v_g = ',num2str(t*vg),'    t * v_0 = ',num2str(t*v0)]);


t=2/vg;  % fester Zeitpunkt so dass t*vg=2m
k=k0;  % rumliche Frequenz (n Halbwellen in z=1:100)
% 
Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
% 
xi0=xi; % Welle mit k0 (fr die grafische Darstellung)
xi=zeros(size(xi));  % zur Initialisierung
xiwp=zeros(size(xi));  % zur Initialisierung
for k=k0-3*Dk:dk:k0+3*Dk;  % harmonische Wellen in 3*Dk links und rechts des Max.
    %
    Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
    vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
    xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
    %
    xiwp=xiwp+xi;  % Wellenpaket = Summe der harmonischen Wellen
end
figure(32)
plot(z,10*xi0,z,xiwp);
axis([min(z) max(z) -Maxxi Maxxi]);
title([' t * v_g = ',num2str(t*vg),'    t * v_0 = ',num2str(t*v0)]);


% Fr den konstruierten Puls wird die Zeit schrittweise erhht: 
% der Puls luft durch den Raum. Dabei hat er zu t=0 die minimale
% Unschrfe. Die Verteilung in k ist immer gleich breit, aber in x ist das
% Wellenpaket bei t=0 am schmalsten, dann luft es auseinander. (Es luft
% von t<0 auch zusammen, d.h. bei t<0 ist die Unschrfe auch grer als bei
% t=0.)

for t=(-1:0.01:1)/v0;  % Zeitpunkte
    k=k0;  % rumliche Frequenz (n Halbwellen in z=1:100)
    %
    Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
    vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
    xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
    %
    xi0=xi; % Welle mit k0 (fr die grafische Darstellung)
    xi=zeros(size(xi));  % Initialisierung
    xiwp=zeros(size(xi));  % Initialisierung
    for k=k0-3*Dk:dk:k0+3*Dk  % harmonische Wellen in 3*Dk links und rechts des Max.
        %
        Ak=exp(-((k-k0)^2/(2*Dk^2))); % Gewichtung mit Gauss-Kurve
        vk=v0+dvdk*(k-k0); % Geschwindigkeit inkl. Dispersion
        xi=Ak*cos(k*(z-vk*t));  % gewichtete harmonische Welle
        %
        xiwp=xiwp+xi;  % Wellenpaket = Summe der harmonischen Wellen
    end
    figure(42)
    plot(z,10*xi0,z,xiwp);
    axis([min(z) max(z) -Maxxi Maxxi]);
    %axis([t*vg-1 t*vg+1 -Maxxi Maxxi]);
    title([' t * v_g = ',num2str(t*vg),'    t * v_0 = ',num2str(t*v0)]);
    pause(0.02);
    if t==0 pause(1); end
end

